__project__ = "fast-to-sql"
__version__ = "2.1.14"
__keywords__ = ["pandas", "to_sql", "fast", "sql"]
__author__ = "Jarred Glaser"
__author_email__ = "jarred.glaser@gmail.com"
__url__ = "https://github.com/jdglaser/fast-to-sql"
__platforms__ = "ALL"
__requires__=['pandas', 'pyodbc']

__classifiers__ = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
    'Programming Language :: Python :: 3.8',
    'License :: OSI Approved :: MIT License'
]

__extra_requires__ = {
}